summaryrefslogtreecommitdiffstats
path: root/source/slang/slang-repro.cpp
diff options
context:
space:
mode:
authorjsmall-nvidia <jsmall@nvidia.com>2020-11-19 04:14:48 -0500
committerGitHub <noreply@github.com>2020-11-19 01:14:48 -0800
commitb59451020eee59cd52e4d8231360ebed4fc59adb (patch)
treea5a77794097ee99bbef91b8f28be8788284e7736 /source/slang/slang-repro.cpp
parentac41b9956681d54f4487ff06922017f2753d0c45 (diff)
File system refactor (#1611)
* #include an absolute path didn't work - because paths were taken to always be relative. * WIP FileSystem refactor. * Made loadFile load the file in binary mode. * Fixed some comments. Fixed typo in RelativePath - not used 'fixedPath'.
Diffstat (limited to 'source/slang/slang-repro.cpp')
-rw-r--r--source/slang/slang-repro.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/source/slang/slang-repro.cpp b/source/slang/slang-repro.cpp
index 80ef0322e..f9cc415c0 100644
--- a/source/slang/slang-repro.cpp
+++ b/source/slang/slang-repro.cpp
@@ -1149,7 +1149,7 @@ struct LoadContext
Path::createDirectory(dirPath);
// Set up a file system to write into this directory
- RelativeFileSystem relFileSystem(OSFileSystemExt::getSingleton(), dirPath);
+ RelativeFileSystem relFileSystem(OSFileSystem::getMutableSingleton(), dirPath);
return extractFiles(base, requestState, &relFileSystem);
}
@@ -1382,7 +1382,7 @@ static SlangResult _calcCommandLine(OffsetBase& base, ReproUtil::RequestState* r
return SLANG_OK;
}
/* static */SlangResult ReproUtil::extractFiles(OffsetBase& base, RequestState* requestState, ISlangFileSystemExt* fileSystem)
{
StringBuilder builder;
@@ -1382,7 +1382,7 @@ static SlangResult _calcCommandLine(OffsetBase& base, ReproUtil::RequestState* r
return SLANG_OK;
}
-/* static */SlangResult ReproUtil::extractFiles(OffsetBase& base, RequestState* requestState, ISlangFileSystemExt* fileSystem)
+/* static */SlangResult ReproUtil::extractFiles(OffsetBase& base, RequestState* requestState, ISlangMutableFileSystem* fileSystem)
{
StringBuilder builder;